Scenario API reference
======================

scenario
========

.. automodule:: scenario
   :special-members: __call__

.. automodule:: scenario.errors


Indices
=======

* :ref:`genindex`
* :ref:`modindex`
* :ref:`search`
